@@ -2,7 +2,7 @@
   +----------------------------------------------------------------------+
   | PHP Version 7                                                        |
   +----------------------------------------------------------------------+
-  | Copyright (c) 2006-2020 The PHP Group                                |
+  | Copyright (c) The PHP Group                                          |
   +----------------------------------------------------------------------+
   | This source file is subject to version 3.01 of the PHP license,      |
   | that is bundled with this package in the file LICENSE, and is        |
@@ -47,6 +47,9 @@ using namespace drv;
 
 static zend_class_entry *mysqlx_doc_result_class_entry;
 
+ZEND_BEGIN_ARG_INFO_EX(arginfo_mysqlx_doc_result__construct, 0, ZEND_RETURN_VALUE, 0)
+ZEND_END_ARG_INFO()
+
 ZEND_BEGIN_ARG_INFO_EX(arginfo_mysqlx_doc_result__fetch_one, 0, ZEND_RETURN_VALUE, 0)
 ZEND_END_ARG_INFO()
 
@@ -179,7 +182,7 @@ MYSQL_XDEVAPI_PHP_METHOD(mysqlx_doc_result, getWarnings)
 }
 
 static const zend_function_entry mysqlx_doc_result_methods[] = {
-	PHP_ME(mysqlx_doc_result, __construct,			nullptr,																ZEND_ACC_PRIVATE)
+	PHP_ME(mysqlx_doc_result, __construct, arginfo_mysqlx_doc_result__construct, ZEND_ACC_PRIVATE)
 	PHP_ME(mysqlx_doc_result, fetchOne,				arginfo_mysqlx_doc_result__fetch_one,				ZEND_ACC_PUBLIC)
 	PHP_ME(mysqlx_doc_result, fetchAll,				arginfo_mysqlx_doc_result__fetch_all,				ZEND_ACC_PUBLIC)
 
