@@ -2,7 +2,7 @@
   +----------------------------------------------------------------------+
   | PHP Version 7                                                        |
   +----------------------------------------------------------------------+
-  | Copyright (c) 2006-2020 The PHP Group                                |
+  | Copyright (c) The PHP Group                                          |
   +----------------------------------------------------------------------+
   | This source file is subject to version 3.01 of the PHP license,      |
   | that is bundled with this package in the file LICENSE, and is        |
@@ -47,6 +47,9 @@ using namespace drv;
 static zend_class_entry * mysqlx_sql_statement_class_entry;
 static zend_class_entry * mysqlx_statement_class_entry;
 
+ZEND_BEGIN_ARG_INFO_EX(arginfo_mysqlx_sql_statement__construct, 0, ZEND_RETURN_VALUE, 0)
+ZEND_END_ARG_INFO()
+
 
 ZEND_BEGIN_ARG_INFO_EX(arginfo_mysqlx_sql_statement__bind, 0, ZEND_RETURN_VALUE, 1)
 	ZEND_ARG_INFO(no_pass_by_ref, param)
@@ -645,7 +648,7 @@ MYSQL_XDEVAPI_PHP_METHOD(mysqlx_sql_statement, getNextResult)
 }
 
 static const zend_function_entry mysqlx_sql_statement_methods[] = {
-	PHP_ME(mysqlx_sql_statement, __construct,		nullptr,													ZEND_ACC_PRIVATE)
+	PHP_ME(mysqlx_sql_statement, __construct, arginfo_mysqlx_sql_statement__construct, ZEND_ACC_PRIVATE)
 	PHP_ME(mysqlx_sql_statement, bind,				arginfo_mysqlx_sql_statement__bind,				ZEND_ACC_PUBLIC)
 	PHP_ME(mysqlx_sql_statement, execute,			arginfo_mysqlx_sql_statement__execute,													ZEND_ACC_PUBLIC)
 	PHP_ME(mysqlx_sql_statement, hasMoreResults,	arginfo_mysqlx_sql_statement__has_more_results,	ZEND_ACC_PUBLIC)
@@ -857,7 +860,7 @@ MYSQL_XDEVAPI_PHP_METHOD(mysqlx_statement, getNextResult)
 }
 
 static const zend_function_entry mysqlx_statement_methods[] = {
-	PHP_ME(mysqlx_statement, __construct,		nullptr,													ZEND_ACC_PRIVATE)
+	PHP_ME(mysqlx_statement, __construct, arginfo_mysqlx_sql_statement__construct, ZEND_ACC_PRIVATE)
 	PHP_ME(mysqlx_statement, hasMoreResults,	arginfo_mysqlx_sql_statement__has_more_results,	ZEND_ACC_PUBLIC)
 	PHP_ME(mysqlx_statement, getResult,		arginfo_mysqlx_sql_statement__get_result, 			ZEND_ACC_PUBLIC)
 	PHP_ME(mysqlx_statement, getNextResult,	arginfo_mysqlx_sql_statement__get_result, 			ZEND_ACC_PUBLIC)
